@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyBrowser.cpp 8178 2008-04-01 00:27:59Z chpe $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
@@ -84,6 +84,7 @@
 #include <nsIWebPageDescriptor.h>
 #include <nsMemory.h>
 #include <nsServiceManagerUtils.h>
+#include <nsCDefaultURIFixup.h>
 
 #ifdef HAVE_MOZILLA_PSM
 #include <nsICertificateDialogs.h>
@@ -364,14 +365,14 @@ EphyDOMLinkEventListener::HandleEvent (nsIDOMEvent* aDOMEvent)
 					 &decision);
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 		if (decision != nsIContentPolicy::ACCEPT) return NS_OK;
-		
-		/* Hide password part */
-		nsCString user;
-		favUri->GetUsername (user);
-		favUri->SetUserPass (user);
+
+		NS_ENSURE_TRUE (mOwner->mFixup, NS_OK);
+                nsCOMPtr<nsIURI> exposableURI;
+                rv = mOwner->mFixup->CreateExposableURI (favUri, getter_AddRefs (exposableURI));
+                NS_ENSURE_SUCCESS (rv, rv);
 
 		nsCString spec;
-		favUri->GetSpec (spec);
+		exposableURI->GetSpec (spec);
 
 		/* ok, we accept this as a valid favicon for this site */
 		g_signal_emit_by_name (mOwner->mEmbed, "ge_favicon", spec.get());
@@ -429,13 +430,12 @@ EphyDOMLinkEventListener::HandleEvent (nsIDOMEvent* aDOMEvent)
 			rv = GetDocURI (linkElement, getter_AddRefs (docUri));
 			NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && docUri, NS_ERROR_FAILURE);
 
-			/* Hide password part */
-			nsCString user;
-			docUri->GetUsername (user);
-			docUri->SetUserPass (user);
+                        nsCOMPtr<nsIURI> exposableURI;
+                        rv = mOwner->mFixup->CreateExposableURI (docUri, getter_AddRefs (exposableURI));
+                        NS_ENSURE_SUCCESS (rv, rv);
 
 			nsCString resolvedLink;
-			rv = docUri->Resolve (cLink, resolvedLink);
+			rv = exposableURI->Resolve (cLink, resolvedLink);
 			NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 			linkElement->GetAttribute (NS_LITERAL_STRING ("title"), value);
@@ -830,6 +830,7 @@ EphyBrowser::EphyBrowser ()
 #endif
 , mContextMenuListener(nsnull)
 , mInitialized(PR_FALSE)
+, mZoom(0.0)
 {
 	LOG ("EphyBrowser ctor (%p)", this);
 }
@@ -902,6 +903,9 @@ nsresult EphyBrowser::Init (EphyEmbed *embed)
 	NS_ENSURE_SUCCESS (rv, rv);
 #endif /* HAVE_MOZILLA_PSM */
 
+        mFixup = do_GetService (NS_URIFIXUP_CONTRACTID);
+        NS_ENSURE_TRUE (mFixup, NS_ERROR_FAILURE);
+
 	mInitialized = PR_TRUE;
 
 	return NS_OK;
@@ -1189,7 +1193,9 @@ nsresult EphyBrowser::SetZoom (float aZoom)
 	nsCOMPtr<nsIMarkupDocumentViewer> mdv = do_QueryInterface(contentViewer);
 	NS_ENSURE_TRUE (mdv, NS_ERROR_FAILURE);
 
-	return mdv->SetTextZoom (aZoom);
+	nsresult rv = mdv->SetTextZoom (aZoom);
+	mZoom = aZoom;
+	return rv;
 }
 
 nsresult EphyBrowser::GetContentViewer (nsIContentViewer **aViewer)
@@ -1204,6 +1210,10 @@ nsresult EphyBrowser::GetContentViewer (nsIContentViewer **aViewer)
 
 nsresult EphyBrowser::GetZoom (float *aZoom)
 {
+	if (mZoom != 0) {
+		*aZoom = mZoom;
+		return NS_OK;
+	}
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIContentViewer> contentViewer;	
@@ -1213,7 +1223,9 @@ nsresult EphyBrowser::GetZoom (float *aZoom)
 	nsCOMPtr<nsIMarkupDocumentViewer> mdv = do_QueryInterface(contentViewer);
 	NS_ENSURE_TRUE (mdv, NS_ERROR_FAILURE);
 
-	return mdv->GetTextZoom (aZoom);
+	nsresult rv = mdv->GetTextZoom (aZoom);
+	mZoom = *aZoom;
+	return rv;
 }
 
 nsresult
