@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GeckoPrintService.cpp 7773 2007-12-16 12:55:03Z chpe $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
@@ -46,8 +46,7 @@
 #include "ephy-prefs.h"
 #include "ephy-stock-icons.h"
 
-#include "AutoJSContextStack.h"
-#include "AutoWindowModalState.h"
+#include "AutoModalDialog.h"
 #include "EphyUtils.h"
 #include "GeckoPrintSession.h"
 
@@ -121,17 +120,13 @@ GeckoPrintService::ShowPrintDialog (nsIDOMWindow *aParent,
   rv = aSettings->GetHowToEnableFrameUI (&frameUI);
   NS_ENSURE_SUCCESS (rv, rv);
 
-  GtkWidget *parent = EphyUtils::FindGtkParent (aParent);
+  AutoModalDialog modalDialog (aParent, PR_TRUE);
+  if (!modalDialog.ShouldShow ())
+    return NS_ERROR_ABORT;
+
+  GtkWindow *parent = modalDialog.GetParent ();
   NS_ENSURE_TRUE(parent, NS_ERROR_INVALID_POINTER);
 
-  AutoJSContextStack stack;
-  rv = stack.Init ();
-  if (NS_FAILED (rv)) {
-    return rv;
-  }
-
-  AutoWindowModalState modalState (aParent);
-
   EphyEmbedShell *shell = ephy_embed_shell_get_default ();
 
   GladeXML *xml = glade_xml_new (ephy_file ("print.glade"),
@@ -200,7 +195,7 @@ GeckoPrintService::ShowPrintDialog (nsIDOMWindow *aParent,
 
   gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
-  int response = gtk_dialog_run (GTK_DIALOG (dialog));
+  int response = modalDialog.Run (GTK_DIALOG (dialog));
   gtk_widget_hide (dialog);
 
   GtkPrinter *printer = gtk_print_unix_dialog_get_selected_printer (print_dialog);
@@ -522,7 +517,6 @@ GeckoPrintService::TranslateSettings (GtkPrintSettings *aGtkSettings,
 				      PRBool aIsForPrinting,
 				      nsIPrintSettings *aSettings)
 {
-  NS_ENSURE_ARG (aPrinter);
   NS_ENSURE_ARG (aGtkSettings);
   NS_ENSURE_ARG (aPageSetup);
 
@@ -534,7 +528,12 @@ GeckoPrintService::TranslateSettings (GtkPrintSettings *aGtkSettings,
   }
 #endif
 
-  GtkPrintCapabilities capabilities = gtk_printer_get_capabilities (aPrinter);
+  GtkPrintCapabilities capabilities;
+  if (aIsForPrinting) {
+    NS_ENSURE_TRUE (aPrinter, NS_ERROR_FAILURE);
+
+    capabilities = gtk_printer_get_capabilities (aPrinter);
+  }
 
   /* Initialisation */
   aSettings->SetIsInitializedFromPrinter (PR_FALSE); /* FIXME: PR_TRUE? */
@@ -665,7 +664,10 @@ GeckoPrintService::TranslateSettings (GtkPrintSettings *aGtkSettings,
   aSettings->SetPrintInColor (gtk_print_settings_get_use_color (aGtkSettings));
 
   aSettings->SetPaperSizeUnit(nsIPrintSettings::kPaperSizeMillimeters);
+
+#ifndef HAVE_GECKO_1_9
   aSettings->SetPaperSize (nsIPrintSettings::kPaperSizeDefined);
+#endif
 
   GtkPaperSize *paperSize = gtk_page_setup_get_paper_size (aPageSetup);
   if (!paperSize) {
@@ -733,7 +735,7 @@ GeckoPrintService::TranslateSettings (GtkPrintSettings *aGtkSettings,
 
   /* FIXME: only if GTK_PRINT_CAPABILITY_SCALE is not set? */
   aSettings->SetScaling (gtk_print_settings_get_scale (aGtkSettings) / 100.0);
-  gtk_print_settings_set_scale (aGtkSettings, 1.0);
+  gtk_print_settings_set_scale (aGtkSettings, 100.0);
 
   aSettings->SetShrinkToFit (PR_FALSE); /* FIXME setting */
     
